@@ -15,7 +15,8 @@ Usage::
 import sys
 from typing import IO, Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
+from botocore.response import StreamingBody
 
 from .literals import (
     ActionTypeType,
@@ -97,18 +98,25 @@ class Exceptions:
     TooManyTagsException: Type[BotocoreClientError]
 
 
-class ACMPCAClient:
+class ACMPCAClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ACMPCAClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#can_paginate)
         """
 
@@ -123,7 +131,9 @@ class ACMPCAClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreateCertificateAuthorityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority)
+        Creates a root or subordinate private certificate authority (CA).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#create_certificate_authority)
         """
 
@@ -135,7 +145,9 @@ class ACMPCAClient:
         AuditReportResponseFormat: AuditReportResponseFormatType
     ) -> CreateCertificateAuthorityAuditReportResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority_audit_report)
+        Creates an audit report that lists every time that your CA private key is used.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority_audit_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#create_certificate_authority_audit_report)
         """
 
@@ -148,7 +160,10 @@ class ACMPCAClient:
         SourceAccount: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.create_permission)
+        Grants one or more permissions on a private CA to the AWS Certificate Manager
+        (ACM) service principal (`acm.amazonaws.com` ).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.create_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#create_permission)
         """
 
@@ -156,7 +171,9 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, PermanentDeletionTimeInDays: int = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.delete_certificate_authority)
+        Deletes a private certificate authority (CA).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.delete_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#delete_certificate_authority)
         """
 
@@ -164,13 +181,18 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, Principal: str, SourceAccount: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.delete_permission)
+        Revokes permissions on a private CA granted to the AWS Certificate Manager (ACM)
+        service principal (acm.amazonaws.com).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.delete_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#delete_permission)
         """
 
     def delete_policy(self, *, ResourceArn: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.delete_policy)
+        Deletes the resource-based policy attached to a private CA.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.delete_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#delete_policy)
         """
 
@@ -178,7 +200,10 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str
     ) -> DescribeCertificateAuthorityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority)
+        Lists information about your private certificate authority (CA) or one that has
+        been shared with you.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#describe_certificate_authority)
         """
 
@@ -186,7 +211,12 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, AuditReportId: str
     ) -> DescribeCertificateAuthorityAuditReportResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority_audit_report)
+        Lists information about a specific audit report created by calling the
+        `CreateCertificateAuthorityAuditReport <https://docs.aws.amazon.com/acm-
+        pca/latest/APIReference/API_CreateCertificateAuthorityAuditReport.html>`__
+        action.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority_audit_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#describe_certificate_authority_audit_report)
         """
 
@@ -198,7 +228,9 @@ class ACMPCAClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#generate_presigned_url)
         """
 
@@ -206,7 +238,10 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, CertificateArn: str
     ) -> GetCertificateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.get_certificate)
+        Retrieves a certificate from your private CA or one that has been shared with
+        you.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_certificate)
         """
 
@@ -214,7 +249,10 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str
     ) -> GetCertificateAuthorityCertificateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_certificate)
+        Retrieves the certificate and certificate chain for your private certificate
+        authority (CA) or one that has been shared with you.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_certificate_authority_certificate)
         """
 
@@ -222,13 +260,18 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str
     ) -> GetCertificateAuthorityCsrResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_csr)
+        Retrieves the certificate signing request (CSR) for your private certificate
+        authority (CA).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_csr)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_certificate_authority_csr)
         """
 
     def get_policy(self, *, ResourceArn: str) -> GetPolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.get_policy)
+        Retrieves the resource-based policy attached to a private CA.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_policy)
         """
 
@@ -236,11 +279,13 @@ class ACMPCAClient:
         self,
         *,
         CertificateAuthorityArn: str,
-        Certificate: Union[bytes, IO[bytes]],
-        CertificateChain: Union[bytes, IO[bytes]] = None
+        Certificate: Union[bytes, IO[bytes], StreamingBody],
+        CertificateChain: Union[bytes, IO[bytes], StreamingBody] = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.import_certificate_authority_certificate)
+        Imports a signed private CA certificate into ACM Private CA.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.import_certificate_authority_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#import_certificate_authority_certificate)
         """
 
@@ -248,16 +293,19 @@ class ACMPCAClient:
         self,
         *,
         CertificateAuthorityArn: str,
-        Csr: Union[bytes, IO[bytes]],
+        Csr: Union[bytes, IO[bytes], StreamingBody],
         SigningAlgorithm: SigningAlgorithmType,
-        Validity: ValidityTypeDef,
-        ApiPassthrough: ApiPassthroughTypeDef = None,
+        Validity: "ValidityTypeDef",
+        ApiPassthrough: "ApiPassthroughTypeDef" = None,
         TemplateArn: str = None,
-        ValidityNotBefore: ValidityTypeDef = None,
+        ValidityNotBefore: "ValidityTypeDef" = None,
         IdempotencyToken: str = None
     ) -> IssueCertificateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.issue_certificate)
+        Uses your private certificate authority (CA), or one that has been shared with
+        you, to issue a client certificate.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.issue_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#issue_certificate)
         """
 
@@ -269,7 +317,11 @@ class ACMPCAClient:
         ResourceOwner: ResourceOwnerType = None
     ) -> ListCertificateAuthoritiesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.list_certificate_authorities)
+        Lists the private certificate authorities that you created by using the
+        `CreateCertificateAuthority <https://docs.aws.amazon.com/acm-
+        pca/latest/APIReference/API_CreateCertificateAuthority.html>`__ action.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.list_certificate_authorities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#list_certificate_authorities)
         """
 
@@ -277,7 +329,10 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListPermissionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.list_permissions)
+        List all permissions on a private CA, if any, granted to the AWS Certificate
+        Manager (ACM) service principal (acm.amazonaws.com).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.list_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#list_permissions)
         """
 
@@ -285,19 +340,26 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListTagsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.list_tags)
+        Lists the tags, if any, that are associated with your private CA or one that has
+        been shared with you.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#list_tags)
         """
 
     def put_policy(self, *, ResourceArn: str, Policy: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.put_policy)
+        Attaches a resource-based policy to a private CA.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.put_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#put_policy)
         """
 
     def restore_certificate_authority(self, *, CertificateAuthorityArn: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.restore_certificate_authority)
+        Restores a certificate authority (CA) that is in the `DELETED` state.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.restore_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#restore_certificate_authority)
         """
 
@@ -309,7 +371,9 @@ class ACMPCAClient:
         RevocationReason: RevocationReasonType
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.revoke_certificate)
+        Revokes a certificate that was issued inside ACM Private CA.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.revoke_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#revoke_certificate)
         """
 
@@ -317,7 +381,9 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, Tags: List["TagTypeDef"]
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.tag_certificate_authority)
+        Adds one or more tags to your private CA.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.tag_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#tag_certificate_authority)
         """
 
@@ -325,7 +391,9 @@ class ACMPCAClient:
         self, *, CertificateAuthorityArn: str, Tags: List["TagTypeDef"]
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.untag_certificate_authority)
+        Remove one or more tags from your private CA.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.untag_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#untag_certificate_authority)
         """
 
@@ -337,7 +405,9 @@ class ACMPCAClient:
         Status: CertificateAuthorityStatusType = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Client.update_certificate_authority)
+        Updates the status or configuration of a private certificate authority (CA).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.update_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#update_certificate_authority)
         """
 
@@ -346,7 +416,8 @@ class ACMPCAClient:
         self, operation_name: Literal["list_certificate_authorities"]
     ) -> ListCertificateAuthoritiesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Paginator.ListCertificateAuthorities)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listcertificateauthoritiespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Paginator.ListCertificateAuthorities)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listcertificateauthoritiespaginator)
         """
 
     @overload
@@ -354,19 +425,22 @@ class ACMPCAClient:
         self, operation_name: Literal["list_permissions"]
     ) -> ListPermissionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Paginator.ListPermissions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listpermissionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Paginator.ListPermissions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listpermissionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tags"]) -> ListTagsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Paginator.ListTags)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listtagspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Paginator.ListTags)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listtagspaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["audit_report_created"]) -> AuditReportCreatedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Waiter.audit_report_created)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#auditreportcreatedwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#auditreportcreatedwaiter)
         """
 
     @overload
@@ -374,11 +448,13 @@ class ACMPCAClient:
         self, waiter_name: Literal["certificate_authority_csr_created"]
     ) -> CertificateAuthorityCSRCreatedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Waiter.certificate_authority_csr_created)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateauthoritycsrcreatedwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateauthoritycsrcreatedwaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["certificate_issued"]) -> CertificateIssuedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/acm-pca.html#ACMPCA.Waiter.certificate_issued)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateissuedwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateissuedwaiter)
         """
